<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsd="http://www.w3.org/2001/XMLSchema"
	xmlns:xs="http://www.w3.org/2001/XMLSchema">

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<!-- Prefisso per l'alias del namespace. Default = 'xs:' -->
	<xsl:param name="Prefix" select="'xs:'"/>

	<!-- Nomi di alcuni elementi -->
	<xsl:param name="AttributeName" select="concat ($Prefix, 'attribute')"/>
	<xsl:param name="AttributeGroupName" select="concat ($Prefix, 'attributeGroup')"/>
	<xsl:param name="ElementName" select="concat ($Prefix, 'element')"/>

	<!-- Serve per verificare se il browser supporta XSLT 1.0 -->
	<xsl:template match="XXX_TAG_FITTIZIO_XXX">
		<xsl:element name="Errore">
			<xsl:text>Questo browser non supporta XSLT 1.0! Quindi il resto di questo documento e' solo rumore da non tenere in considerazione</xsl:text>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                        MAIN                                       -->
	<!-- **************************************************************** -->
	<xsl:template match="/">
		<!-- Applico ricorsivamente il foglio XSLT -->
		<xsl:apply-templates select="xs:schema"/>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                     SCHEMA                                    -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:schema">
		<xsl:element name="sm">
			<!-- Applico ricorsivamente il foglio XSLT -->
			<xsl:apply-templates select="xs:element"/>

			<xsl:apply-templates select="xs:attributeGroup">
				<xsl:with-param name="ParentName" select="'sm'" />
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                     element                                   -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:element">
		<!-- Aggiungo un elemento con nome 'element' -->
		<xsl:element name="element">
			<!-- Valore dell'eventuale attributo di nome 'type' -->
			<xsl:variable name="TypeValue">
				<xsl:choose>
					<!-- Se il valore dell'attributo di nome 'type' ha la stringa $Prefix come prefisso  -->
					<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'type'], $Prefix)) )">
						<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], $Prefix))"/>
					</xsl:when>
					<!-- Se il valore dell'attributo di nome 'type' contiene il carattere ':'  -->
					<xsl:when test="boolean (contains (@*[name() = 'type'], ':'))">
						<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], ':'))"/>
					</xsl:when>
					<!-- Altrimenti: se il valore dell'attributo di nome 'type' NON ha la stringa $Prefix come prefisso  -->
					<xsl:otherwise>
						<xsl:value-of select="normalize-space (@*[name() = 'type'])"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<xsl:choose>
				<!-- Se l'elemento corrente ha un attributo di nome 'type' -->
				<xsl:when test="boolean (string-length ($TypeValue) > 0)">
					<!-- Scrivo un element name con valore uguale al valore dell'attributo 'name' dell'elemento corrente -->
					<xsl:element name="name">
						<xsl:value-of select="@*[name() = 'name']"/>
					</xsl:element>

					<!-- Scrivo un element domain -->
					<xsl:element name="domain">
						<!-- Nome dell'elemento type -->
						<xsl:variable name="TypeName">
							<xsl:choose>
								<!-- Se il nome dell'elemento type ha la stringa $Prefix come prefisso  -->
								<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (name(//child::*[@name = $TypeValue]), $Prefix)) )">
									<xsl:value-of select="normalize-space (substring-after(name(//child::*[@name = $TypeValue]), $Prefix))"/>
								</xsl:when>
								<!-- Se il nome dell'elemento type contiene la stringa ':'  -->
								<xsl:when test="boolean (contains (name(//child::*[@name = $TypeValue]), ':'))">
									<xsl:value-of select="normalize-space (substring-after(name(//child::*[@name = $TypeValue]), ':'))"/>
								</xsl:when>
								<!-- Altrimenti: se il nome dell'elemento type NON ha la stringa $Prefix come prefisso  -->
								<xsl:otherwise>
									<xsl:value-of select="normalize-space (name(//child::*[@name = $TypeValue]))"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>

						<!-- Decodifico l'attributo 'type' dell'elemento corrente -->
						<xsl:call-template name="TypeDecoder">
							<xsl:with-param name="TypeValue" select="$TypeValue" />
						</xsl:call-template>
					</xsl:element>

					<xsl:apply-templates select="//child::*[@name = $TypeValue]/child::*[name(.) = $AttributeGroupName]">
						<xsl:with-param name="ParentName" select="ancestor-or-self::*/@*[name() = 'name']" />
					</xsl:apply-templates>

					<xsl:apply-templates select="//child::*[@name = $TypeValue]/child::*[name(.) = $AttributeName]">
						<xsl:with-param name="ParentName" select="ancestor-or-self::*/@*[name() = 'name']" />
					</xsl:apply-templates>
				</xsl:when>
				<xsl:otherwise>
					<!-- Valore dell'eventuale attributo di nome 'ref' -->
					<xsl:variable name="RefValue">
						<xsl:choose>
							<!-- Se il valore dell'attributo di nome 'ref' ha la stringa 'xs:' come prefisso  -->
							<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'ref'], $Prefix)) )">
								<xsl:value-of select="normalize-space (substring-after (@*[name() = 'ref'], $Prefix))"/>
							</xsl:when>
							<!-- Se il valore dell'attributo di nome 'ref' contiene il carattere ':'  -->
							<xsl:when test="boolean (contains (@*[name() = 'ref'], ':'))">
								<xsl:value-of select="normalize-space (substring-after (@*[name() = 'ref'], ':'))"/>
							</xsl:when>
							<!-- Altrimenti: se il valore dell'attributo di nome 'ref' NON ha la stringa 'xs:' come prefisso  -->
							<xsl:otherwise>
								<xsl:value-of select="normalize-space (@*[name() = 'ref'])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>

					<xsl:choose>
						<!-- Se l'elemento corrente ha un attributo di nome 'ref' -->
						<xsl:when test="boolean (string-length ($RefValue) > 0)">
							<xsl:element name="ref">
								<xsl:value-of select="$RefValue"/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<!-- Scrivo il nome ed il valore dell'attributo 'name' dell'elemento corrente -->
							<xsl:element name="name">
								<xsl:value-of select="@*[name() = 'name']"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
	
			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<!-- Applico ricorsivamente il foglio XSLT -->
			<xsl:apply-templates />

			<xsl:if test="boolean ( (string-length ($TypeValue) = 0) and (child::*/node()[name()=$AttributeName]) )">
				<xsl:apply-templates select="child::*/node()[name()=$AttributeGroupName]">
					<xsl:with-param name="ParentName" select="@name" />
				</xsl:apply-templates>
	
				<xsl:apply-templates select="child::*/node()[name()=$AttributeName]">
					<xsl:with-param name="ParentName" select="@name" />
				</xsl:apply-templates>
			</xsl:if>

		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                         key                                       -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:key">
		<xsl:element name="key">
				<!-- Aggiungo un attributo con nome 'name' e con valore uguale al valore dell'attributo 'name' dell'elemento corrente -->
			<xsl:element name="name">
				<xsl:value-of select="@*[name() = 'name']"/>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<!-- Applico ricorsivamente il foglio XSLT -->
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                     key_ref                                   -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:keyref">
		<xsl:element name="key_ref">
			<!-- Aggiungo un attributo con nome 'name' e con valore uguale al valore dell'attributo 'name' dell'elemento corrente -->
			<xsl:element name="name">
				<xsl:value-of select="@*[name() = 'name']"/>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<!-- Applico ricorsivamente il foglio XSLT -->
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                   attribute                                  -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:attribute">
		<xsl:param name="ParentName" />

		<xsl:choose>
			<xsl:when test="boolean ( $ParentName = '' )">
			</xsl:when>

			<xsl:otherwise>
				<xsl:element name="attribute_of_element">
					<!-- Aggiungo un attributo con nome 'name' e con valore uguale al valore dell'attributo 'name' dell'elemento corrente -->
					<xsl:element name="name">
						<xsl:value-of select="@*[name() = 'name']"/>
					</xsl:element>
					<xsl:element name="element_name">
						<xsl:value-of select="$ParentName"/>
					</xsl:element>

					<!-- Valore dell'eventuale attributo di nome 'use' -->
					<xsl:variable name="UseValue">
						<xsl:value-of select="normalize-space (@*[name() = 'use'])"/>
					</xsl:variable>

					<!-- Se l'elemento corrente ha un attributo di nome 'use' -->
					<xsl:if test="boolean (string-length ($UseValue) > 0)">
						<xsl:choose>
							<xsl:when test="boolean ($UseValue = 'required')">
								<xsl:element name="is_required">
									<xsl:text>true</xsl:text>
								</xsl:element>
							</xsl:when>
							<xsl:when test="boolean ($UseValue = 'optional')">
								<xsl:element name="is_optional">
									<xsl:text>true</xsl:text>
								</xsl:element>
							</xsl:when>
							<xsl:when test="boolean ($UseValue = 'prohibited')">
								<xsl:element name="is_prohibited">
									<xsl:text>true</xsl:text>
								</xsl:element>
							</xsl:when>
						</xsl:choose>
					</xsl:if>
		
					<!-- Valore dell'eventuale attributo di nome 'type' -->
					<xsl:variable name="TypeValue">
						<xsl:choose>
							<!-- Se il valore dell'attributo di nome 'type' ha la stringa $Prefix come prefisso  -->
							<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'type'], $Prefix)) )">
								<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], $Prefix))"/>
							</xsl:when>
							<!-- Se il valore dell'attributo di nome 'type' contiene il carattere ':'  -->
							<xsl:when test="boolean (contains (@*[name() = 'type'], ':'))">
								<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], ':'))"/>
							</xsl:when>
							<!-- Altrimenti: se il valore dell'attributo di nome 'type' NON ha la stringa $Prefix come prefisso  -->
							<xsl:otherwise>
								<xsl:value-of select="normalize-space (@*[name() = 'type'])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>

					<xsl:choose>
						<!-- Se l'elemento corrente ha un attributo di nome 'type' -->
						<xsl:when test="boolean (string-length ($TypeValue) > 0)">
							<!-- Scrivo un element domain -->
							<xsl:element name="domain">
								<!-- Nome dell'elemento type -->
								<xsl:variable name="TypeName">
									<xsl:choose>
										<!-- Se il nome dell'elemento type ha la stringa $Prefix come prefisso  -->
										<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (name(//child::*[@name = $TypeValue]), $Prefix)) )">
											<xsl:value-of select="normalize-space (substring-after(name(//child::*[@name = $TypeValue]), $Prefix))"/>
										</xsl:when>
										<!-- Se il nome dell'elemento type contiene la stringa ':'  -->
										<xsl:when test="boolean (contains (name(//child::*[@name = $TypeValue]), ':'))">
											<xsl:value-of select="normalize-space (substring-after(name(//child::*[@name = $TypeValue]), ':'))"/>
										</xsl:when>
										<!-- Altrimenti: se il nome dell'elemento type NON ha la stringa $Prefix come prefisso  -->
										<xsl:otherwise>
											<xsl:value-of select="normalize-space (name(//child::*[@name = $TypeValue]))"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>

								<!-- Decodifico l'attributo 'type' dell'elemento corrente -->
								<xsl:call-template name="TypeDecoder">
									<xsl:with-param name="TypeValue" select="$TypeValue" />
								</xsl:call-template>
							</xsl:element>

							<xsl:apply-templates select="//child::*[@name = $TypeValue]/child::*[name(.) = $AttributeName]">
								<xsl:with-param name="ParentName" select="@name" />
							</xsl:apply-templates>

							<!-- Copio tutti gli attributi dell'elemento corrente -->
							<xsl:apply-templates select="@*"/>
						</xsl:when>
						<!-- Altrimenti: se l'elemento corrente NON ha un attributo di nome 'type' -->
						<xsl:otherwise>
							<!-- Copio tutti gli attributi dell'elemento corrente -->
							<xsl:apply-templates select="@*"/>
						</xsl:otherwise>
					</xsl:choose>
		
					<!-- Applico ricorsivamente il foglio XSLT ai figli dell'elemento corrente -->
					<xsl:apply-templates select="child::*">
						<xsl:with-param name="ParentName" select="@name" />
					</xsl:apply-templates>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- **************************************************************** -->
	<!--                             attributeGROUP                            -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:attributeGroup">
		<xsl:param name="ParentName" />

		<xsl:choose>
			<xsl:when test="boolean ( $ParentName = '' )">
			</xsl:when>

			<xsl:otherwise>
				<xsl:element name="attribute_of_element">
					<!-- Aggiungo un elemento con nome 'name' e con valore uguale al valore dell'attributo 'name' dell'elemento corrente -->
					<xsl:if test="boolean ( string-length (@*[name() = 'name']) > 0 )">
						<xsl:element name="name">
							<xsl:value-of select="@*[name() = 'name']"/>
						</xsl:element>
					</xsl:if>

					<xsl:if test="boolean ( string-length ($ParentName) > 0 )">
						<xsl:element name="element_name">
							<xsl:value-of select="$ParentName"/>
						</xsl:element>
					</xsl:if>
		
					<!-- Aggiungo un elemento con nome 'ref' e con valore uguale al valore dell'attributo 'ref' dell'elemento corrente -->
					<xsl:if test="boolean ( string-length (@*[name() = 'ref']) > 0 )">
						<!-- Valore dell'eventuale attributo di nome 'ref' -->
						<xsl:variable name="RefValue">
							<xsl:choose>
								<!-- Se il valore dell'attributo di nome 'ref' ha la stringa 'xs:' come prefisso  -->
								<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'ref'], $Prefix)) )">
									<xsl:value-of select="normalize-space (substring-after (@*[name() = 'ref'], $Prefix))"/>
								</xsl:when>
								<!-- Se il valore dell'attributo di nome 'ref' contiene il carattere ':'  -->
								<xsl:when test="boolean (contains (@*[name() = 'ref'], ':'))">
									<xsl:value-of select="normalize-space (substring-after (@*[name() = 'ref'], ':'))"/>
								</xsl:when>
								<!-- Altrimenti: se il valore dell'attributo di nome 'ref' NON ha la stringa 'xs:' come prefisso  -->
								<xsl:otherwise>
									<xsl:value-of select="normalize-space (@*[name() = 'ref'])"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>

						<xsl:element name="ref">
							<xsl:value-of select="$RefValue"/>
						</xsl:element>
					</xsl:if>

					<!-- Copio tutti gli attributi dell'elemento corrente -->
					<xsl:apply-templates select="@*"/>
		
					<!-- Applico ricorsivamente il foglio XSLT ai figli dell'elemento corrente -->
					<xsl:apply-templates select="child::*">
						<xsl:with-param name="ParentName" select="@name" />
					</xsl:apply-templates>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                  restriction                                -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:restriction">
		<!-- Valore dell'eventuale attributo di nome 'base' -->
		<xsl:variable name="BaseValue">
			<xsl:choose>
				<!-- Se il valore dell'attributo di nome 'base' ha la stringa $Prefix come prefisso  -->
				<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'base'], $Prefix)) )">
					<xsl:value-of select="normalize-space (substring-after (@*[name() = 'base'], $Prefix))"/>
				</xsl:when>
				<!-- Se il valore dell'attributo di nome 'base' contiene il carattere ':'  -->
				<xsl:when test="boolean (contains (@*[name() = 'base'], ':'))">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'base'], ':'))"/>
				</xsl:when>
				<!-- Altrimenti: se il valore dell'attributo di nome 'base' NON ha la stringa $Prefix come prefisso  -->
				<xsl:otherwise>
					<xsl:value-of select="normalize-space (@*[name() = 'base'])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Decodifico l'attributo 'type' dell'elemento corrente -->
		<xsl:call-template name="TypeDecoder">
			<xsl:with-param name="TypeValue" select="$BaseValue" />
		</xsl:call-template>

		<!-- Se l'elemento corrente ha figli -->
		<xsl:if test="boolean (count(child::*) > 0)">
			<xsl:element name="restriction">
				<!-- Applico ricorsivamente il foglio XSLT ai figli dell'elemento corrente -->
				<xsl:apply-templates select="child::*"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                   extension                                  -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:extension">
		<xsl:param name="TypeValue" />

		<!-- Valore dell'eventuale attributo di nome 'base' -->
		<xsl:variable name="BaseValue">
			<xsl:choose>
				<!-- Se il valore dell'attributo di nome 'base' ha la stringa $Prefix come prefisso  -->
				<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'base'], $Prefix)) )">
					<xsl:value-of select="normalize-space (substring-after (@*[name() = 'base'], $Prefix))"/>
				</xsl:when>
				<!-- Se il valore dell'attributo di nome 'base' contiene il carattere ':'  -->
				<xsl:when test="boolean (contains (@*[name() = 'base'], ':'))">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'base'], ':'))"/>
				</xsl:when>
				<!-- Altrimenti: se il valore dell'attributo di nome 'base' NON ha la stringa $Prefix come prefisso  -->
				<xsl:otherwise>
					<xsl:value-of select="normalize-space (@*[name() = 'base'])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:element name="extension">
			<!-- Decodifico l'attributo 'type' dell'elemento corrente -->
			<xsl:call-template name="TypeDecoder">
				<xsl:with-param name="TypeValue" select="$BaseValue" />
			</xsl:call-template>

			<!-- Applico ricorsivamente il foglio XSLT ai figli dell'elemento corrente -->
			<xsl:apply-templates select="child::*"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                          @*                                        -->
	<!-- **************************************************************** -->
	<xsl:template match="@*">
		<!-- Nome dell'attributo corrente -->
		<xsl:variable name="AttributeName">
			<xsl:value-of select="name(.)"/>
		</xsl:variable>
		<!-- Valore dell'attributo corrente -->
		<xsl:variable name="AttributeValue">
			<xsl:value-of select="."/>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="boolean ($AttributeName = 'name' or $AttributeName = 'type' or $AttributeName = 'use' or $AttributeName = 'ref')">
			</xsl:when>
			<!-- min_occur -->
			<xsl:when test="boolean ($AttributeName = 'minOccurs')">
				<xsl:element name="min_occur">
					<xsl:choose>
						<!-- Se il valore dell'attributo corrente ha la stringa 'xs:' come prefisso  -->
						<xsl:when test="boolean ($AttributeValue = 'unbounded')">
							<xsl:text>N</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$AttributeValue"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:when>
			<!-- max_occur -->
			<xsl:when test="boolean ($AttributeName = 'maxOccurs')">
				<xsl:element name="max_occur">
					<xsl:choose>
						<!-- Se il valore dell'attributo corrente ha la stringa 'xs:' come prefisso  -->
						<xsl:when test="boolean ($AttributeValue = 'unbounded')">
							<xsl:text>N</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$AttributeValue"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:when>
			<!-- block -->
			<xsl:when test="boolean ($AttributeName = 'block')">
				<xsl:element name="block">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- final -->
			<xsl:when test="boolean ($AttributeName = 'final')">
				<xsl:element name="final">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- is_mixed -->
			<xsl:when test="boolean ($AttributeName = 'mixed')">
				<xsl:if test="boolean ($AttributeValue = 'true')">
					<xsl:element name="is_mixed">
						<xsl:text>true</xsl:text>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<!-- is_abstract -->
			<xsl:when test="boolean ($AttributeName = 'abstract')">
				<xsl:if test="boolean ($AttributeValue = 'true')">
					<xsl:element name="is_abstract">
						<xsl:text>true</xsl:text>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<!-- is_nullable -->
			<xsl:when test="boolean ($AttributeName = 'nillable')">
				<xsl:if test="boolean ($AttributeValue = 'true')">
					<xsl:element name="is_nullable">
						<xsl:text>true</xsl:text>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<!-- SUBSTITUTIONGROUP -->
			<xsl:when test="boolean ($AttributeName = 'substitutionGroup')">
				<xsl:element name="substitution_group">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- default -->
			<xsl:when test="boolean ($AttributeName = 'default')">
				<xsl:element name="default">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- fixed -->
			<xsl:when test="boolean ($AttributeName = 'fixed')">
				<xsl:element name="fixed">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- form -->
			<xsl:when test="boolean ($AttributeName = 'form')">
				<xsl:element name="form">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- id -->
			<xsl:when test="boolean ($AttributeName = 'id')">
				<xsl:element name="id">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- process_contents -->
			<xsl:when test="boolean ($AttributeName = 'processContents')">
				<xsl:element name="process_contents">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- namespace -->
			<xsl:when test="boolean ($AttributeName = 'namespace')">
				<xsl:element name="namespace">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<!-- refer -->
			<xsl:when test="boolean ($AttributeName = 'refer')">
				<xsl:element name="refer">
					<xsl:value-of select="$AttributeValue"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="{name()}">
					<xsl:choose>
						<!-- Se il valore dell'attributo corrente ha la stringa 'xs:' come prefisso  -->
						<xsl:when test="boolean ($AttributeValue = 'unbounded')">
							<xsl:text>N</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$AttributeValue"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                          ALL                                       -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:all">
		<xsl:element name="list">
			<xsl:element name="is_all">
				<xsl:text>true</xsl:text>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                          ANY                                      -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:any">
<!--
		<xsl:element name="list">
-->
			<xsl:element name="is_any">
				<xsl:text>true</xsl:text>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
<!--
		</xsl:element>
-->
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                      CHOICE                                     -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:choice">
		<xsl:element name="list">
			<xsl:element name="is_choice">
				<xsl:text>true</xsl:text>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                      GROUP                                     -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:group">
		<xsl:element name="list">
			<xsl:element name="is_group">
				<xsl:text>true</xsl:text>
			</xsl:element>

			<xsl:element name="name">
				<xsl:value-of select="@*[name() = 'name']"/>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                         list                                       -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:list">
<!--
		<xsl:element name="list">
			<xsl:element name="IS_list">
				<xsl:text>true</xsl:text>
			</xsl:element>
-->

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
<!--
		</xsl:element>
-->
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                        UNION                                     -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:union">
		<xsl:element name="list">
<!--
			<xsl:element name="is_union">
				<xsl:text>true</xsl:text>
			</xsl:element>
-->

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:for-each select="xs:simpleType">
				<xsl:element name="domain">
					<xsl:apply-templates />
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                   SEQUENCE                                  -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:sequence">
		<xsl:element name="list">
			<xsl:element name="is_sequence">
				<xsl:text>true</xsl:text>
			</xsl:element>

			<!-- Copio tutti gli attributi dell'elemento corrente -->
			<xsl:apply-templates select="@*"/>

			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 MAXINCLUSIVE                              -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:maxInclusive">
		<xsl:element name="max_inclusive">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 MININCLUSIVE                               -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:minInclusive">
		<xsl:element name="min_inclusive">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 MAXEXCLUSIVE                            -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:maxExclusive">
		<xsl:element name="max_exclusive">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                MINEXCLUSIVE                               -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:minExclusive">
		<xsl:element name="min_exclusive">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 MAXLENGTH                                  -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:maxLength">
		<xsl:element name="max_length">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                  MINLENGTH                                  -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:minLength">
		<xsl:element name="min_length">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                    pattern                                    -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:pattern">
		<xsl:element name="pattern">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                enumerATION                               -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:enumeration">
		<xsl:element name="enum">
			<xsl:element name="VALUE">
				<xsl:value-of select="@*[name() = 'value']"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                               FRACTIONDIGITS                             -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:fractionDigits">
		<xsl:element name="fraction_digits">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                  TOTALDIGITS                                -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:totalDigits">
		<xsl:element name="total_digits">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                  WHITEspace                                -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:whiteSpace">
		<xsl:element name="white_space">
			<xsl:value-of select="@*[name() = 'value']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                   SELECTOR                                   -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:selector">
		<xsl:element name="element_name">
			<xsl:value-of select="@*[name() = 'xpath']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                        FIELD                                      -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:field">
		<xsl:element name="field_attr">
			<xsl:value-of select="@*[name() = 'xpath']"/>
		</xsl:element>
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                               SIMPLECONTENT                             -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:simpleContent">
		<xsl:element name="is_simplecontent">
			<xsl:text>true</xsl:text>
		</xsl:element>

		<!-- Applico ricorsivamente il foglio XSLT -->
		<xsl:apply-templates />
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                             COMPLEXCONTENT                           -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:complexContent">
		<xsl:element name="is_complexcontent">
			<xsl:text>true</xsl:text>
		</xsl:element>

		<!-- Applico ricorsivamente il foglio XSLT -->
		<xsl:apply-templates />
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                   SIMPLETYPE                                -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:simpleType">
		<!-- Valore dell'eventuale attributo di nome 'type' -->
		<xsl:variable name="TypeValue">
			<xsl:choose>
				<!-- Se il valore dell'attributo di nome 'type' ha la stringa $Prefix come prefisso  -->
				<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'name'], $Prefix)) )">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], $Prefix))"/>
				</xsl:when>
				<!-- Se il valore dell'attributo di nome 'type' contiene il carattere ':'  -->
				<xsl:when test="boolean (contains (@*[name() = 'name'], ':'))">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], ':'))"/>
				</xsl:when>
				<!-- Altrimenti: se il valore dell'attributo di nome 'type' NON ha la stringa $Prefix come prefisso  -->
				<xsl:otherwise>
					<xsl:value-of select="normalize-space (@*[name() = 'name'])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="ChildTypeName">
			<xsl:value-of select="normalize-space (substring-after(child::*/@*[name()='base'], ':'))"/>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="boolean (name(//child::*[@name = $ChildTypeName]) = 'simpleType' )">
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="is_simple_type">
					<xsl:text>true</xsl:text>
				</xsl:element>

				<xsl:if test="boolean (string-length ($TypeValue) > 0)">
					<xsl:element name="name">
						<xsl:value-of select="$TypeValue"/>
					</xsl:element>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Applico ricorsivamente il foglio XSLT -->
		<xsl:apply-templates />
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 COMPLEXTYPE                              -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:complexType">
		<xsl:element name="is_complex_type">
			<xsl:text>true</xsl:text>
		</xsl:element>

		<!-- Valore dell'eventuale attributo di nome 'type' -->
		<xsl:variable name="TypeValue">
			<xsl:choose>
				<!-- Se il valore dell'attributo di nome 'type' ha la stringa $Prefix come prefisso  -->
				<xsl:when test="boolean ((string-length ($Prefix) > 0) and (starts-with (@*[name() = 'name'], $Prefix)) )">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], $Prefix))"/>
				</xsl:when>
				<!-- Se il valore dell'attributo di nome 'type' contiene il carattere ':'  -->
				<xsl:when test="boolean (contains (@*[name() = 'name'], ':'))">
					<xsl:value-of select="normalize-space (substring-after(@*[name() = 'type'], ':'))"/>
				</xsl:when>
				<!-- Altrimenti: se il valore dell'attributo di nome 'type' NON ha la stringa $Prefix come prefisso  -->
				<xsl:otherwise>
					<xsl:value-of select="normalize-space (@*[name() = 'name'])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:if test="boolean (string-length ($TypeValue) > 0)">
			<xsl:element name="name">
				<xsl:value-of select="$TypeValue"/>
			</xsl:element>
		</xsl:if>

		<!-- Copio tutti gli attributi dell'elemento corrente -->
		<xsl:apply-templates select="@*"/>

		<!-- Applico ricorsivamente il foglio XSLT -->
		<xsl:apply-templates />

	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                  TypeDecoder                                -->
	<!-- **************************************************************** -->
	<xsl:template name="TypeDecoder">
		<xsl:param name="TypeValue" />

		<xsl:choose>
			<!-- BOOLEAN  -->
			<xsl:when test="boolean ($TypeValue = 'boolean')">
				<xsl:element name="is_boolean">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- DOUBLE  -->
			<xsl:when test="boolean ($TypeValue = 'double')">
				<xsl:element name="is_double">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- INTEGer  -->
			<xsl:when test="boolean ($TypeValue = 'integer')">
				<xsl:element name="is_integer">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- INTEGer  -->
			<xsl:when test="boolean ($TypeValue = 'int')">
				<xsl:element name="is_integer">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- FLOAT  -->
			<xsl:when test="boolean ($TypeValue = 'float')">
				<xsl:element name="is_float">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- DECIMAL  -->
			<xsl:when test="boolean ($TypeValue = 'decimal')">
				<xsl:element name="is_decimal">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- TIME  -->
			<xsl:when test="boolean ($TypeValue = 'time')">
				<xsl:element name="is_time">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- STRING  -->
			<xsl:when test="boolean ($TypeValue = 'string')">
				<xsl:element name="is_string">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- DATE  -->
			<xsl:when test="boolean ($TypeValue = 'date')">
				<xsl:element name="is_date">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- ENTITY  -->
			<xsl:when test="boolean ($TypeValue = 'ENTITY')">
				<xsl:element name="is_entity">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- ENTITIES  -->
			<xsl:when test="boolean ($TypeValue = 'ENTITIES')">
				<xsl:element name="is_entities">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- id  -->
			<xsl:when test="boolean ($TypeValue = 'id')">
				<xsl:element name="is_id">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- idref  -->
			<xsl:when test="boolean ($TypeValue = 'idref')">
				<xsl:element name="is_idref">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- idrefS  -->
			<xsl:when test="boolean ($TypeValue = 'idrefS')">
				<xsl:element name="is_idrefs">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- NMTOKEN  -->
			<xsl:when test="boolean ($TypeValue = 'NMTOKEN')">
				<xsl:element name="is_nmtoken">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- NMTOKENS  -->
			<xsl:when test="boolean ($TypeValue = 'NMTOKENS')">
				<xsl:element name="is_nmtokens">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- NOTATION  -->
			<xsl:when test="boolean ($TypeValue = 'NOTATION')">
				<xsl:element name="is_notation">
					<xsl:text>true</xsl:text>
				</xsl:element>
			</xsl:when>
			<!-- *** ALTRIMENTI ***  -->
			<xsl:otherwise>
				<xsl:if test="boolean (count(//child::*[@name = $TypeValue]) > 0)">
					<xsl:apply-templates select="//child::*[@name = $TypeValue]"/>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- **************************************************************** -->
	<!--                                 ANNOTATION                                -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:annotation">
	</xsl:template>

	<!-- **************************************************************** -->
	<!--                              DOCUMENTATION                            -->
	<!-- **************************************************************** -->
	<xsl:template match="xs:documentation">
	</xsl:template>

</xsl:transform>
